@@ -1,7 +1,7 @@
 /*
  * libics: Image Cytometry Standard file reading and writing.
  *
- * Copyright 2015-2017:
+ * Copyright 2015-2018:
  *   Scientific Volume Imaging Holding B.V.
  *   Laapersveld 63, 1213 VB Hilversum, The Netherlands
  *   https://www.svi.nl
@@ -280,7 +280,7 @@ size_t IcsGetDataSize(const ICS *ics)
 {
     if (ics == NULL) return 0;
     if (ics->dimensions == 0) return 0;
-    return IcsGetImageSize(ics) * IcsGetBytesPerSample(ics);
+    return IcsGetImageSize(ics) * (size_t)IcsGetBytesPerSample(ics);
 }
 
 
@@ -288,7 +288,7 @@ size_t IcsGetDataSize(const ICS *ics)
 size_t IcsGetImelSize(const ICS *ics)
 {
     if (ics != NULL) {
-        return IcsGetBytesPerSample(ics);
+        return (size_t)IcsGetBytesPerSample(ics);
     } else {
         return 0;
     }
@@ -429,7 +429,7 @@ Ics_Error IcsGetROIData(ICS          *ics,
         if (sampling[i] < 1 || offset[i] + size[i] > ics->dim[i].size)
             return IcsErr_IllegalROI;
     }
-    imelSize = IcsGetBytesPerSample(ics);
+    imelSize = (size_t)IcsGetBytesPerSample(ics);
     roiSize = imelSize;
     for (i = 0; i < p; i++) {
         roiSize *= (size[i] + sampling[i] - 1) / sampling[i];
@@ -472,7 +472,7 @@ Ics_Error IcsGetROIData(ICS          *ics,
             }
             curLoc += bufSize;
             for (j=0; j < size[0]; j += sampling[0]) {
-                memcpy(dest, buf + i * imelSize, imelSize);
+                memcpy(dest, buf + (unsigned)i * imelSize, imelSize);
                 dest += imelSize;
             }
             for (i = 1; i < p; i++) {
@@ -550,7 +550,7 @@ Ics_Error IcsGetDataWithStrides(ICS             *ics,
     char            *buf;
     char            *dest = (char*)destPtr;
     char            *out;
-
+    (void)n; /* we're not using this parameter */
 
     if ((ics == NULL) || (ics->fileMode == IcsFileMode_write))
         return IcsErr_NotValidAction;
@@ -567,7 +567,7 @@ Ics_Error IcsGetDataWithStrides(ICS             *ics,
         }
         stride = b_stride;
     }
-    imelSize = IcsGetBytesPerSample(ics);
+    imelSize = (size_t)IcsGetBytesPerSample(ics);
 
     error = IcsOpenIds(ics);
     if (error) return error;
@@ -714,6 +714,36 @@ Ics_Error IcsSetSource(ICS        *ics,
 }
 
 
+Ics_Error IcsSetByteOrder(ICS           *ics,
+                          Ics_ByteOrder  order) {
+    ICSINIT;
+
+
+    if ((ics == NULL) || (ics->fileMode != IcsFileMode_write))
+        return IcsErr_NotValidAction;
+
+    if (ics->version == 1) return IcsErr_NotValidAction;
+    if (ics->srcFile[0] == '\0') return IcsErr_NotValidAction;
+
+    switch (order) {
+        case IcsByteOrder_littleEndian:
+            IcsFillLittleEndianByteOrder(ics->imel.dataType,
+                                         (int)IcsGetDataTypeSize(ics->imel.dataType),
+                                         ics->byteOrder);
+            break;
+        case IcsByteOrder_bigEndian:
+            IcsFillBigEndianByteOrder(ics->imel.dataType,
+                                      (int)IcsGetDataTypeSize(ics->imel.dataType),
+                                      ics->byteOrder);
+            break;
+        default:
+            return IcsErr_IllParameter;
+    }
+
+    return error;
+}
+
+
 /* Set the compression method and compression parameter. */
 Ics_Error IcsSetCompression(ICS             *ics,
                             Ics_Compression  compression,
@@ -1117,6 +1147,8 @@ Ics_Error IcsGuessScilType(ICS *ics)
             break;
         case Ics_uint32:
         case Ics_sint32:
+        case Ics_uint64:
+        case Ics_sint64:
         case Ics_real64:
         case Ics_complex64:
             return IcsErr_NoScilType;
@@ -1279,6 +1311,9 @@ const char *IcsGetErrorText(Ics_Error error)
         case IcsErr_TooManyChans:
             msg = "Too many channels specified";
             break;
+        case IcsErr_TooManyDetectors:
+            msg = "Too many detectors specified";
+            break;
         case IcsErr_TooManyDims:
             msg = "Data has too many dimensions";
             break;
